@@ -1,15 +1,16 @@
 package version
 
 import (
+	"context"
 	"fmt"
 
-	"github.com/urfave/cli/v2"
+	"github.com/urfave/cli/v3"
 
 	"github.com/ekristen/aws-nuke/v3/pkg/commands/global"
 	"github.com/ekristen/aws-nuke/v3/pkg/common"
 )
 
-func execute(c *cli.Context) error {
+func execute(_ context.Context, _ *cli.Command) error {
 	fmt.Println(common.AppVersion.Name, "version", common.AppVersion.Summary)
 
 	return nil
