@@ -4,11 +4,12 @@ import (
 	"context"
 	"time"
 
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/service/cloudwatch"
 	"github.com/gotidy/ptr"
 	"go.uber.org/ratelimit"
 
+	"github.com/aws/aws-sdk-go/aws"                //nolint:staticcheck
+	"github.com/aws/aws-sdk-go/service/cloudwatch" //nolint:staticcheck
+
 	"github.com/ekristen/libnuke/pkg/registry"
 	"github.com/ekristen/libnuke/pkg/resource"
 	"github.com/ekristen/libnuke/pkg/types"
