@@ -7,7 +7,7 @@ import (
 
 	"github.com/gotidy/ptr"
 
-	"github.com/aws/aws-sdk-go/service/route53resolver"
+	"github.com/aws/aws-sdk-go/service/route53resolver" //nolint:staticcheck
 	"github.com/aws/aws-sdk-go/service/route53resolver/route53resolveriface"
 
 	"github.com/ekristen/libnuke/pkg/registry"
